@@ -35,6 +35,8 @@
 #include <kernelbuffer.h>
 #include "bc_cat.h"
 
+#include <linux/slab.h>
+
 #include <linux/dma-mapping.h>
 
 #define DEVNAME             "bccat"
@@ -487,8 +489,11 @@ static int __init bc_cat_init(void)
 
     /* texture buffer width should be multiple of 8 for OMAP3 ES3.x,
      * or 32 for ES2.x */
-    width_align = cpu_is_omap3530() && omap_rev_lt_3_0() ? 32 : 8;
-    
+#ifdef PLAT_TI8168  
+   width_align = 8;
+#else
+   width_align = cpu_is_omap3530() && omap_rev_lt_3_0() ? 32 : 8;   
+#endif    
     major = register_chrdev(0, DEVNAME, &bc_cat_fops);
 
     if (major <= 0) {
